@@ -1,7 +1,7 @@
 \unset ECHO
 \i test_setup.sql
 
-SELECT plan(558);
+SELECT plan(675);
 --SELECT * FROM no_plan();
 
 -- This will be rolled back. :-)
@@ -1079,7 +1079,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', 'pg_catalog', '<=', 'integer', 'boolean'::name ),
   true,
   'has_operator( left, schema, name, right, result )',
-  'Operator ("integer" pg_catalog.<= "integer" RETURNS "boolean") should exist',
+  'Operator pg_catalog.<=(integer,integer) RETURNS boolean should exist',
   ''
 );
 
@@ -1095,7 +1095,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', '<=', 'integer', 'boolean'::name ),
   true,
   'has_operator( left, name, right, result )',
-  'Operator ("integer" <= "integer" RETURNS "boolean") should exist',
+  'Operator <=(integer,integer) RETURNS boolean should exist',
   ''
 );
 
@@ -1111,7 +1111,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', '<=', 'integer'::name ),
   true,
   'has_operator( left, name, right )',
-  'Operator ("integer" <= "integer") should exist',
+  'Operator <=(integer,integer) should exist',
   ''
 );
 
@@ -1127,7 +1127,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', 'pg_catalog', '<=', 'text', 'boolean'::name ),
   false,
   'has_operator( left, schema, name, right, result ) fail',
-  'Operator ("integer" pg_catalog.<= text RETURNS "boolean") should exist',
+  'Operator pg_catalog.<=(integer,text) RETURNS boolean should exist',
   ''
 );
 
@@ -1143,7 +1143,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', '<=', 'text', 'boolean'::name ),
   false,
   'has_operator( left, name, right, result ) fail',
-  'Operator ("integer" <= text RETURNS "boolean") should exist',
+  'Operator <=(integer,text) RETURNS boolean should exist',
   ''
 );
 
@@ -1159,7 +1159,7 @@ SELECT * FROM check_test(
   has_operator( 'integer', '<=', 'text'::name ),
   false,
   'has_operator( left, name, right ) fail',
-  'Operator ("integer" <= text) should exist',
+  'Operator <=(integer,text) should exist',
   ''
 );
 
@@ -1178,7 +1178,7 @@ SELECT * FROM check_test(
   has_leftop( 'pg_catalog', '!!', 'bigint', 'numeric'::name ),
   true,
   'has_leftop( schema, name, right, result )',
-  'Operator (pg_catalog.!! "bigint" RETURNS "numeric") should exist',
+  'Left operator pg_catalog.!!(NONE,bigint) RETURNS numeric should exist',
   ''
 );
 
@@ -1194,7 +1194,7 @@ SELECT * FROM check_test(
   has_leftop( '!!', 'bigint', 'numeric'::name ),
   true,
   'has_leftop( name, right, result )',
-  'Operator (!! "bigint" RETURNS "numeric") should exist',
+  'Left operator !!(NONE,bigint) RETURNS numeric should exist',
   ''
 );
 
@@ -1210,7 +1210,7 @@ SELECT * FROM check_test(
   has_leftop( '!!', 'bigint' ),
   true,
   'has_leftop( name, right )',
-  'Operator (!! "bigint") should exist',
+  'Left operator !!(NONE,bigint) should exist',
   ''
 );
 
@@ -1226,7 +1226,7 @@ SELECT * FROM check_test(
   has_leftop( 'pg_catalog', '!!', 'text', 'numeric'::name ),
   false,
   'has_leftop( schema, name, right, result ) fail',
-  'Operator (pg_catalog.!! text RETURNS "numeric") should exist',
+  'Left operator pg_catalog.!!(NONE,text) RETURNS numeric should exist',
   ''
 );
 
@@ -1242,7 +1242,7 @@ SELECT * FROM check_test(
   has_leftop( '!!', 'text', 'numeric'::name ),
   false,
   'has_leftop( name, right, result ) fail',
-  'Operator (!! text RETURNS "numeric") should exist',
+  'Left operator !!(NONE,text) RETURNS numeric should exist',
   ''
 );
 
@@ -1258,7 +1258,7 @@ SELECT * FROM check_test(
   has_leftop( '!!', 'text' ),
   false,
   'has_leftop( name, right ) fail',
-  'Operator (!! text) should exist',
+  'Left operator !!(NONE,text) should exist',
   ''
 );
 
@@ -1277,7 +1277,7 @@ SELECT * FROM check_test(
   has_rightop( 'bigint', 'pg_catalog', '!', 'numeric'::name ),
   true,
   'has_rightop( left, schema, name, result )',
-  'Operator ("bigint" pg_catalog.! RETURNS "numeric") should exist',
+  'Right operator pg_catalog.!(bigint,NONE) RETURNS numeric should exist',
   ''
 );
 
@@ -1293,7 +1293,7 @@ SELECT * FROM check_test(
   has_rightop( 'bigint', '!', 'numeric'::name ),
   true,
   'has_rightop( left, name, result )',
-  'Operator ("bigint" ! RETURNS "numeric") should exist',
+  'Right operator !(bigint,NONE) RETURNS numeric should exist',
   ''
 );
 
@@ -1309,7 +1309,7 @@ SELECT * FROM check_test(
   has_rightop( 'bigint', '!' ),
   true,
   'has_rightop( left, name )',
-  'Operator ("bigint" !) should exist',
+  'Right operator !(bigint,NONE) should exist',
   ''
 );
 
@@ -1325,7 +1325,7 @@ SELECT * FROM check_test(
   has_rightop( 'text', 'pg_catalog', '!', 'numeric'::name ),
   false,
   'has_rightop( left, schema, name, result ) fail',
-  'Operator (text pg_catalog.! RETURNS "numeric") should exist',
+  'Right operator pg_catalog.!(text,NONE) RETURNS numeric should exist',
   ''
 );
 
@@ -1341,7 +1341,7 @@ SELECT * FROM check_test(
   has_rightop( 'text', '!', 'numeric'::name ),
   false,
   'has_rightop( left, name, result ) fail',
-  'Operator (text ! RETURNS "numeric") should exist',
+  'Right operator !(text,NONE) RETURNS numeric should exist',
   ''
 );
 
@@ -1357,7 +1357,7 @@ SELECT * FROM check_test(
   has_rightop( 'text', '!' ),
   false,
   'has_rightop( left, name ) fail',
-  'Operator (text !) should exist',
+  'Right operator !(text,NONE) should exist',
   ''
 );
 
@@ -1561,6 +1561,329 @@ SELECT * FROM check_test(
   ''
 );
 
+/****************************************************************************/
+-- Test domain_type_is() and domain_type_isnt().
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'us_postal_code', 'public', 'text', 'whatever'),
+    true,
+    'domain_type_is(schema, domain, schema, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'us_postal_code', 'public'::name, 'text'),
+    true,
+    'domain_type_is(schema, domain, schema, type)',
+    'Domain public.us_postal_code should extend type public.text',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'US_POSTAL_CODE', 'public', 'TEXT', 'whatever'),
+    true,
+    'domain_type_is(schema, DOMAIN, schema, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'us_postal_code', 'public', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, domain, schema, type, desc) fail',
+    'whatever',
+    '        have: public.text
+        want: public.integer'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'zip_code', 'public', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, nondomain, schema, type, desc)',
+    'whatever',
+    '   Domain public.zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'integer', 'public', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, type, schema, type, desc) fail',
+    'whatever',
+    '   Domain public.integer does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'us_postal_code', 'text', 'whatever'),
+    true,
+    'domain_type_is(schema, domain, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public'::name, 'us_postal_code', 'text'),
+    true,
+    'domain_type_is(schema, domain, type)',
+    'Domain public.us_postal_code should extend type text', 
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'US_POSTAL_CODE', 'TEXT', 'whatever'),
+    true,
+    'domain_type_is(schema, DOMAIN, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'us_postal_code', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, domain, type, desc) fail',
+    'whatever',
+    '        have: text
+        want: integer'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'zip_code', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, nondomain, type, desc)',
+    'whatever',
+    '   Domain public.zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'public', 'integer', 'integer', 'whatever'),
+    false,
+    'domain_type_is(schema, type, type, desc) fail',
+    'whatever',
+    '   Domain public.integer does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'us_postal_code', 'text', 'whatever'),
+    true,
+    'domain_type_is(domain, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'us_postal_code', 'text'),
+    true,
+    'domain_type_is(domain, type)',
+    'Domain us_postal_code should extend type text', 
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'US_POSTAL_CODE', 'TEXT', 'whatever'),
+    true,
+    'domain_type_is(DOMAIN, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'us_postal_code', 'integer', 'whatever'),
+    false,
+    'domain_type_is(domain, type, desc) fail',
+    'whatever',
+    '        have: text
+        want: integer'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'zip_code', 'integer', 'whatever'),
+    false,
+    'domain_type_is(nondomain, type, desc)',
+    'whatever',
+    '   Domain zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_is( 'integer', 'integer', 'whatever'),
+    false,
+    'domain_type_is(type, type, desc) fail',
+    'whatever',
+    '   Domain integer does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'us_postal_code', 'public', 'integer', 'whatever'),
+    true,
+    'domain_type_isnt(schema, domain, schema, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'us_postal_code', 'public'::name, 'integer'),
+    true,
+    'domain_type_isnt(schema, domain, schema, type)',
+    'Domain public.us_postal_code should not extend type public.integer',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'US_POSTAL_CODE', 'public', 'INTEGER', 'whatever'),
+    true,
+    'domain_type_isnt(schema, DOMAIN, schema, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'us_postal_code', 'public', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, domain, schema, type, desc) fail',
+    'whatever',
+    '        have: public.text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'US_POSTAL_CODE', 'public', 'TEXT', 'whatever'),
+    false,
+    'domain_type_isnt(schema, DOMAIN, schema, TYPE, desc) fail',
+    'whatever',
+    '        have: public.text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'zip_code', 'public', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, nondomain, schema, type, desc)',
+    'whatever',
+    '   Domain public.zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'integer', 'public', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, type, schema, type, desc)',
+    'whatever',
+    '   Domain public.integer does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'us_postal_code', 'integer', 'whatever'),
+    true,
+    'domain_type_isnt(schema, domain, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public'::name, 'us_postal_code', 'integer'),
+    true,
+    'domain_type_isnt(schema, domain, type)',
+    'Domain public.us_postal_code should not extend type integer', 
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'US_POSTAL_CODE', 'INTEGER', 'whatever'),
+    true,
+    'domain_type_isnt(schema, DOMAIN, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'us_postal_code', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, domain, type, desc) fail',
+    'whatever',
+    '        have: text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'US_POSTAL_CODE', 'TEXT', 'whatever'),
+    false,
+    'domain_type_isnt(schema, DOMAIN, TYPE, desc) fail',
+    'whatever',
+    '        have: text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'zip_code', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, nondomain, type, desc)',
+    'whatever',
+    '   Domain public.zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'public', 'integer', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(schema, type, type, desc)',
+    'whatever',
+    '   Domain public.integer does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'us_postal_code', 'integer', 'whatever'),
+    true,
+    'domain_type_isnt(domain, type, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'US_POSTAL_CODE', 'INTEGER', 'whatever'),
+    true,
+    'domain_type_isnt(DOMAIN, TYPE, desc)',
+    'whatever',
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'us_postal_code', 'integer'),
+    true,
+    'domain_type_isnt(domain, type)',
+    'Domain us_postal_code should not extend type integer', 
+    ''
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'us_postal_code', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(domain, type, desc) fail',
+    'whatever',
+    '        have: text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'US_POSTAL_CODE', 'TEXT', 'whatever'),
+    false,
+    'domain_type_isnt(DOMAIN, TYPE, desc) fail',
+    'whatever',
+    '        have: text
+        want: anything else'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'zip_code', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(nondomain, type, desc)',
+    'whatever',
+    '   Domain zip_code does not exist'
+);
+
+SELECT * FROM check_test(
+    domain_type_isnt( 'integer', 'text', 'whatever'),
+    false,
+    'domain_type_isnt(type, type, desc)',
+    'whatever',
+    '   Domain integer does not exist'
+);
+
 /****************************************************************************/
 -- Finish the tests and clean up.
 SELECT * FROM finish();
